<?php
/**
 * Modern WP Themes functions and definitions
 *
 * @package Modern WP Themes
 */

/**
 * Required: set 'ot_theme_mode' filter to true.
 */
 	add_filter( 'ot_show_pages', '__return_false' );
	add_filter( 'ot_show_new_layout', '__return_false' );
	add_filter( 'ot_theme_mode', '__return_true' );

/**
 * Required: include OptionTree.
 */
load_template( trailingslashit( get_template_directory() ) . 'ot-loader.php' );
/**
 * Theme Options
 */
load_template( trailingslashit( get_template_directory() ) . 'inc/theme-options.php' );

// Load dynamic styles
load_template( trailingslashit( get_template_directory() ) . 'inc/dynamic-styles.php' ); 


if ( ! function_exists( 'modernwpthemes_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
 
function modernwpthemes_setup() {
	
	/**
 	* Set the content width based on the theme's design and stylesheet.
 	*/
	if ( ! isset( $content_width ) ) {
	$content_width = 1170; /* pixels */
	}

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Modern WP Themes, use a find and replace
	 * to change 'modernwpthemes' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'modernwpthemes', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	
	add_theme_support( 'post-thumbnails' );
	
	add_image_size( 'thumb-small', 70, 70, true );
	add_image_size( 'thumb-medium', 300, 210, true );
	add_image_size( 'thumb-full', 750, 346, true );
	add_image_size( 'thumb-featured', 250, 175, true );


	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'modernwpthemes' ),
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );
	

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'modernwpthemes_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
	) );
}
endif; // modernwpthemes_setup
add_action( 'after_setup_theme', 'modernwpthemes_setup' );

/**
 * Register widgetized area and update sidebar with default widgets.
 */
function modernwpthemes_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'modernwpthemes' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title"><span>',
		'after_title'   => '</span></h1>',
	) );
	
    register_sidebar(array(
    	'id' => 'footer-widget-1',
    	'name' =>  __( 'Footer Widget 1', 'modernwpthemes' ),
    	'description' =>  __( 'Used for footer widget area', 'modernwpthemes' ),
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h1 class="widget-title"><span>',
    	'after_title' => '</span></h1>',
    ));

    register_sidebar(array(
      'id' => 'footer-widget-2',
      'name' =>  __( 'Footer Widget 2', 'modernwpthemes' ),
      'description' =>  __( 'Used for footer widget area', 'modernwpthemes' ),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h1 class="widget-title"><span>',
      'after_title' => '</span></h1>',
    ));

    register_sidebar(array(
      'id' => 'footer-widget-3',
      'name' =>  __( 'Footer Widget 3', 'modernwpthemes' ),
      'description' =>  __( 'Used for footer widget area', 'modernwpthemes' ),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h1 class="widget-title"><span>',
      'after_title' => '</span></h1>',
    ));	
	
    register_sidebar(array(
      'id' => 'footer-widget-4',
      'name' =>  __( 'Footer Widget 4', 'modernwpthemes' ),
      'description' =>  __( 'Used for footer widget area', 'modernwpthemes' ),
      'before_widget' => '<div id="%1$s" class="widget %2$s">',
      'after_widget' => '</div>',
      'before_title' => '<h1 class="widget-title"><span>',
      'after_title' => '</span></h1>',
    ));	

}
add_action( 'widgets_init', 'modernwpthemes_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
function modernwpthemes_scripts() {
	$protocol = is_ssl() ? 'https' : 'http';
	$query_args = array(
		'family' => 'Oswald:400,300,700',);
	wp_enqueue_style( 'modernwpthemes-fonts', add_query_arg( $query_args, "$protocol://fonts.googleapis.com/css" ) );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css' );
	
	wp_enqueue_style( 'modernwpthemes-bootstrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
	wp_enqueue_style( 'modernwpthemes-style', get_stylesheet_uri() );

	wp_enqueue_script('modernwpthemes-bootstrapjs', get_template_directory_uri().'/js/bootstrap.min.js', array('jquery') );
	wp_enqueue_script( 'modernwpthemes-superfish', get_template_directory_uri() . '/js/superfish.js', array( 'jquery' ) );
	wp_enqueue_script( 'modernwpthemes-supersubs', get_template_directory_uri() . '/js/supersubs.js', array( 'jquery' ) );
	wp_enqueue_script( 'modernwpthemes-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20130115', true );
    wp_enqueue_script( 'modernwpthemes-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false );
	wp_enqueue_script( 'modernwpthemes-flexslider', get_template_directory_uri() . '/js/jquery.flexslider.min.js', array( 'jquery' ),'', false );
	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'modernwpthemes_scripts' );

/**
 * Mobile Menu Enqueue scripts and styles
 */
function modernwpthemes_responsive_menu()
{
//meanmenu

 wp_enqueue_style('meanmenu', get_template_directory_uri() . '/css/meanmenu.css', 'style');
}

add_action('wp_enqueue_scripts', 'modernwpthemes_responsive_menu');

function modernwpthemes_custom_scripts_function() {
 if ( !is_admin() ) {
 
 wp_enqueue_script('jquery');  //Grabs the latest version of jQuery from WordPress
 
 wp_register_script('meanmenu', get_template_directory_uri() . '/js/jquery.meanmenu.js', array('jquery'), false );

 wp_enqueue_script('meanmenu');
 }
}

add_action('wp_enqueue_scripts', 'modernwpthemes_custom_scripts_function');



/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * Add custom widgets
 */
require get_template_directory() . '/inc/custom-widgets.php';



/*  TGM plugin activation
/* ------------------------------------ */
	require_once dirname( __FILE__ ) . '/inc/class-tgm-plugin-activation.php';
	function modernwpthemes_plugins() {
		
		// Add the following plugins
		$plugins = array(
			array(
				'name' 				=> 'WP-PageNavi',
				'slug' 				=> 'wp-pagenavi',
				'required'			=> false,
				'force_activation' 	=> false,
				'force_deactivation'=> false,
			),
		);	
		tgmpa( $plugins );
	}
	add_action( 'tgmpa_register', 'modernwpthemes_plugins' );


/*  Custom favicon
/* ------------------------------------ */
	function modernwpthemes_favicon() {
		if ( ot_get_option('favicon') ) {
			echo '<link rel="shortcut icon" href="'.ot_get_option('favicon').'" />'."\n";
		}
	}
	add_filter( 'wp_head', 'modernwpthemes_favicon' );


/*  Tracking code
/* ------------------------------------ */
if ( ! function_exists( 'modernwpthemes_tracking_code' ) ) {

	function modernwpthemes_tracking_code() {
		if ( ot_get_option('tracking_code') ) {
			echo ''.ot_get_option('tracking_code').''."\n";
		}
	}
	
}
add_filter( 'wp_footer', 'modernwpthemes_tracking_code' );


/*  Social links
/* ------------------------------------ */
	function modernwpthemes_social_links() {
		if ( !ot_get_option('social-links') =='' ) {
			$links = ot_get_option('social-links', array());
				if ( !empty( $links ) ) {
					echo '<ul class="social-links">';	
				foreach( $links as $item ) {
					
					// Build each separate html-section only if set
					if ( isset ($item['title']) && !empty($item['title']) ) 
						{ $title = 'title="' .$item['title']. '"'; } else $title = '';
					if ( isset ($item['social-link']) && !empty($item['social-link']) ) 
						{ $link = 'href="' .$item['social-link']. '"'; } else $link = '';
					if ( isset ($item['social-target']) && !empty($item['social-target']) ) 
						{ $target = 'target="' .$item['social-target']. '"'; } else $target = '';
					if ( isset ($item['social-icon']) && !empty($item['social-icon']) ) 
						{ $icon = 'class="fa ' .$item['social-icon']. '"'; } else $icon = '';
					if ( isset ($item['social-color']) && !empty($item['social-color']) ) 
						{ $color = 'style="color: ' .$item['social-color']. ';"'; } else $color = '';
					
					// Put them together
					echo '<li><a class="social-tooltip '.$item['title'].'" '.$title.' '.$link.' '.$target.' ><i '.$icon.' '.$color.'></i></a></li>';
				}
				echo '</ul>';
			}
		}
	}

/*  breadcrumbs
/* ------------------------------------ */
function modernwpthemes_breadcrumbs() {
	echo '<a href="';
	echo home_url();
	echo '" class="home-bread">';
	echo'Home';
	echo "</a>";
		if (is_category() || is_single()) {
			echo "<span>/</span>";
			the_category(' &bull; ');
				if (is_single()) {
					echo " <span>/</span> ";
					the_title();
				}
        } elseif (is_page()) {
            echo "<span>/</span>";
            echo the_title();
		} elseif (is_search()) {
            echo "<span>/</span>Search Results for... ";
			echo '"<em>';
			echo the_search_query();
			echo '</em>"';
        }
    }

