<?php 

/**
 * Initialize the options before anything else. 
 */
add_action( 'admin_init', 'custom_theme_options', 1 );

/**
 * Build the custom settings & update OptionTree.
 */
function custom_theme_options() {
	
	
  /**
   * Get a copy of the saved settings array. 
   */
  $saved_settings = get_option( 'option_tree_settings', array() );
  
  
  /**
   * Custom settings array that will eventually be 
   * passes to the OptionTree Settings API Class.
   */
  $custom_settings = array(
  
	'sections'        => array(
      
	  array(
        'id'          => 'general',
        'title'       => 'General'
      ),
	  
	  array(
        'id'          => 'header',
        'title'       => 'Header'
      ),
	  
	  array(
        'id'          => 'footer',
        'title'       => 'Footer'
      ),
	  
   	  array(
        'id'          => 'layout',
        'title'       => 'Layout'
      ),

  	 array(
        'id'          => 'featured_slider',
        'title'       => 'Featured Slider'
      ),

	   array(
        'id'          => 'social_links',
        'title'       => 'Social Links'
      ),

	   array(
        'id'          => 'styling',
        'title'       => 'Styling'
      ),

  ),
	
	
    'settings'        => array(
     	
		// General: Favicon
		array(
			'id'		=> 'favicon',
			'label'		=> 'Favicon',
			'desc'		=> 'Upload a 16x16px Png/Gif image that will be your favicon',
			'type'		=> 'upload',
			'section'	=> 'general'
		),
		

		// General: Custom CSS
      array(
        'id'          => 'custom_css',
        'label'       => __( 'Custom CSS', 'modernwpthemes' ),
        'desc'        => 'Add your custom CSS styles here. It will be added to the [ dynamic.css ] file',
        'std'         => '',
        'type'        => 'css',
        'section'     => 'general',
        'rows'        => '20',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and'
      ),
	  
	  	// Header: Custom Logo

	  array(
        'id'          => 'custom_logo',
        'label'       => 'Custom Logo',
        'desc'        => 'Upload custom logo image.',
        'std'         => '',
        'type'        => 'upload',
        'section'     => 'header',
        'class'       => '',
      ),
  
	  	// Header: Site Description
		array(
			'id'		=> 'site_description',
			'label'		=> 'Site Description',
			'desc'		=> 'The description that appears next to your logo',
			'type'		=> 'checkbox',
			'section'	=> 'header',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' => 'Disable Site Description'
				 )
				)
			   ),
		
		// Footer: Copyright
		array(
			'id'		=> 'copyright',
			'label'		=> 'Footer Copyright',
			'desc'		=> 'Replace the footer copyright text',
			'type'		=> 'text',
			'section'	=> 'footer'
		),

	  // Layout
	  
      array(
        'id'          => 'sidebar-positions',
        'label'       => __( 'Sidebar Positions', 'modernwpthemes' ),
        'desc'        => sprintf( __( 'You can change the sidebar positions.', 'modernwpthemes' ), '<code>ot_radio_images</code>' ),
        'std'         => 'pull-left',
        'type'        => 'radio-image',
        'section'     => 'layout',
        'rows'        => '',
        'post_type'   => '',
        'taxonomy'    => '',
        'min_max_step'=> '',
        'class'       => '',
        'condition'   => '',
        'operator'    => 'and',
		'choices'	  => array(
		
			array(
				'value'		=> 'pull-right',
				'label'		=> 'Left Sidebar',
				'src'		=> get_template_directory_uri() . '/assets/images/layout/left-sidebar.png'
				),
				
			array(
				'value'		=> 'pull-left',
				'label'		=> 'Right Sidebar',
				'src'		=> get_template_directory_uri() . '/assets/images/layout/right-sidebar.png'
				),
			)
      ),

	// Featured Slider
		array(
			'id'		=> 'featured-posts-include',
			'label'		=> 'Featured Posts',
			'desc'		=> 'If you do not want featured slider you can disable it',
			'type'		=> 'checkbox',
			'section'	=> 'featured_slider',
			'choices'	=> array(
				array( 
					'value' => '5',
					'label' => 'Disable Featured Slider'
				)
			)
		),
		
		// Featured Slider: Featured Category
		array(
			'id'		=> 'featured-category',
			'label'		=> 'Featured Category',
			'desc'		=> 'By not selecting a category, it will show your latest post(s) from all categories',
			'type'		=> 'category-select',
			'section'	=> 'featured_slider'
		),
		
		// Featured Slider: Featured Category Count
		array(
			'id'			=> 'featured-posts-count',
			'label'			=> 'Featured Post Count',
			'desc'			=> 'Max number of featured posts to display. <br /><i>Set to 1 and it will show it without any slider script</i><br /><i>Set it to 0 to disable</i>',
			'std'			=> '5',
			'type'			=> 'numeric-slider',
			'section'		=> 'featured_slider',
			'min_max_step'	=> '0,10,1'
		),

		// Social Links : List
		array(
			'id'		=> 'social-links',
			'label'		=> 'Social Links',
			'desc'		=> 'Create and organize your social links',
			'type'		=> 'list-item',
			'section'	=> 'social_links',
			'choices'	=> array(),
			'settings'	=> array(
				array(
					'id'		=> 'social-icon',
					'label'		=> 'Icon Name',
					'desc'		=> 'Font Awesome icon names [<a href="http://fortawesome.github.io/Font-Awesome/icons/" target="_blank"><strong>View all</strong>]</a>  ',
					'std'		=> 'fa-',
					'type'		=> 'text',
					'choices'	=> array()
				),
				array(
					'id'		=> 'social-link',
					'label'		=> 'Link',
					'desc'		=> 'Enter the full url for your icon button',
					'std'		=> 'http://',
					'type'		=> 'text',
					'choices'	=> array()
				),
				array(
					'id'		=> 'social-target',
					'label'		=> 'Link Options',
					'desc'		=> '',
					'std'		=> '',
					'type'		=> 'checkbox',
					'choices'	=> array(
						array( 
							'value' => '_blank',
							'label' => 'Open in new window'
						)
					)
				)
			)
		),
	   
			
		// Styling: Enable
		array(
			'id'		=> 'dynamic_styles',
			'label'		=> 'Dynamic Styles',
			'desc'		=> 'Enable to use the options below',
			'type'		=> 'checkbox',
			'section'	=> 'styling',
			'choices'	=> array(
				array( 
					'value' => '1',
					'label' => 'Enable'
				)
			)
		),
		
		
		// Styling: Logo Font Color
		
	  	array(
			'id'		=> 'logo_font_color',
			'label'		=> 'Logo - Font Color',
			'desc'		=> 'You can change logo font color<br /><i>Default: #e91b23</i>',
			'std'		=> '#e91b23',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
		),
		
		// Styling: Site Description Color

	  	array(
			'id'		=> 'site_description_font_color',
			'label'		=> 'Site Desciprtion - Font Color',
			'desc'		=> 'You can change site description font color<br /><i>Default: #999999</i>',
			'std'		=> '#999999',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
		),
		
		// Styling: Primary Color
		
	  	array(
			'id'		=> 'primary_color',
			'label'		=> 'Primary Color',
			'desc'		=> 'You can change Site Primary color<br /><i>Default: #e91b23</i>',
			'std'		=> '#e91b23',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
		),

		// Styling: Header Topbar Color
		array(
			'id'		=> 'header_topbar_background',
			'label'		=> 'Header Top Bar Background',
			'desc'		=> 'Set header top bar background color.<br /><i>Default: #ffffff</i>',
			'std'		=> '#ffffff',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			
		),

		// Styling: Header Color
		array(
			'id'		=> 'header_background',
			'label'		=> 'Header Background',
			'desc'		=> 'Set header background color.<br /><i>Default: #ffffff</i>',
			'std'		=> '#ffffff',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
			
		),
		
		
	 // Styling: Footer Widget Color
		array(
			'id'		=> 'footer_widget_background',
			'label'		=> 'Footer Widget Background',
			'desc'		=> 'Set footer widget background color.<br /><i>Default: #fcfcfc</i>',
			'std'		=> '#fcfcfc',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
		),

	   
		 // Styling: Footer Color
		array(
			'id'		=> 'footer_background',
			'label'		=> 'Footer Background',
			'desc'		=> 'Set footer background color.<br /><i>Default: #fcfcfc</i>',
			'std'		=> '#fcfcfc',
			'type'		=> 'colorpicker',
			'section'	=> 'styling',
		),
		
		
		
	 )
  );
  
  
  /* settings are not the same update the DB */
  if ( $saved_settings !== $custom_settings ) {
    update_option( 'option_tree_settings', $custom_settings ); 
  }
  
}

?>